
=========
Resources
=========


Quantum
=======

.. toctree::
   :maxdepth: 2

   quantum/quantum_cognition



Deep Learning
=============

.. toctree::
   :maxdepth: 2

   deep_learning/tools
   deep_learning/recurrent_nn
   deep_learning/recursive_nn
   deep_learning/cnn
   deep_learning/autoencoder
   deep_learning/memory_nn
   deep_learning/gan
   deep_learning/init
   deep_learning/normalization
   deep_learning/tricks


Speech Technology
=================

.. toctree::
   :maxdepth: 2

   speech_technology/speech2text
   speech_technology/text2speech


Natural Language
================

.. toctree::
   :maxdepth: 2

   natural_language/question_answering
   natural_language/language_modeling
   natural_language/answering_selection
   natural_language/word_extraction
   natural_language/others
   natural_language/sources


Computer Vision
===============

.. toctree::
   :maxdepth: 2


Artificial Intelligence
=======================

.. toctree::
   :maxdepth: 2

   artificial_intelligence/what
   artificial_intelligence/viewpoints


Cognitive Science
=================

.. toctree::
   :maxdepth: 2

   cognitive_science/books


Programming
===========

.. toctree::
   :maxdepth: 2

   programming/python



